@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Carla widgets code
-# Copyright (C) 2011-2020 Filipe Coelho <falktx@falktx.com>
+# Copyright (C) 2011-2021 Filipe Coelho <falktx@falktx.com>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -122,13 +122,13 @@ class CarlaAboutW(QDialog):
         self.ui.l_about.setText(self.tr(""
                                         "<br>Version %s"
                                         "<br>Carla is a fully-featured audio plugin host%s.<br>"
-                                        "<br>Copyright (C) 2011-2020 falkTX<br>"
+                                        "<br>Copyright (C) 2011-2021 falkTX<br>"
                                         "" % (VERSION, extraInfo)))
 
         if self.ui.about.palette().color(QPalette.Background).blackF() < 0.5:
             self.ui.l_icons.setPixmap(QPixmap(":/bitmaps/carla_about_black.png"))
             self.ui.ico_example_edit.setPixmap(QPixmap(":/bitmaps/button_file-black.png"))
-            self.ui.ico_example_file.setPixmap(QPixmap(":/bitmaps/button_edit-black.png"))
+            self.ui.ico_example_file.setPixmap(QPixmap(":/scalable/button_edit-black.svg"))
             self.ui.ico_example_gui.setPixmap(QPixmap(":/bitmaps/button_gui-black.png"))
 
         if host.isControl:
@@ -207,9 +207,12 @@ class CarlaAboutW(QDialog):
 
         if usingJuce and (MACOS or WINDOWS):
             self.ui.l_vst2.setText(self.tr("Using JUCE host"))
-            self.ui.l_vst3.setText(self.tr("Using JUCE host"))
         else:
             self.ui.l_vst2.setText(self.tr("About 85&#37; complete (missing vst bank/presets and some minor stuff)"))
+
+        if usingJuce:
+            self.ui.l_vst3.setText(self.tr("Using JUCE host"))
+        else:
             self.ui.line_vst2.hide()
             self.ui.l_vst3.hide()
             self.ui.lid_vst3.hide()
@@ -237,6 +240,9 @@ class CarlaAboutW(QDialog):
 
         self.setWindowFlags(flags)
 
+        if MACOS:
+            self.setWindowModality(Qt.WindowModal)
+
 # ------------------------------------------------------------------------------------------------------------
 # JUCE About dialog
 
@@ -259,6 +265,9 @@ class JuceAboutW(QDialog):
 
         self.setWindowFlags(flags)
 
+        if MACOS:
+            self.setWindowModality(Qt.WindowModal)
+
 # ------------------------------------------------------------------------------------------------------------
 # Plugin Parameter
 
@@ -734,7 +743,9 @@ class PluginEdit(QDialog):
         self.ui.rb_pan.setEnabled(False)
         self.ui.rb_pan.setVisible(False)
 
-        self.setWindowFlags(self.windowFlags() & ~Qt.WindowContextHelpButtonHint)
+        flags  = self.windowFlags()
+        flags &= ~Qt.WindowContextHelpButtonHint
+        self.setWindowFlags(flags)
 
         self.reloadAll()
 
@@ -1036,21 +1047,28 @@ class PluginEdit(QDialog):
         paramOutputList  = []
         paramInputWidth  = 0
         paramOutputWidth = 0
+        unusedParameters = 0
 
         paramInputListFull  = [] # ([params], width)
         paramOutputListFull = [] # ([params], width)
 
-        for i in range(min(parameterCount, self.host.maxParameters)):
-            paramInfo   = self.host.get_parameter_info(self.fPluginId, i)
-            paramData   = self.host.get_parameter_data(self.fPluginId, i)
-            paramRanges = self.host.get_parameter_ranges(self.fPluginId, i)
-            paramValue  = self.host.get_current_parameter_value(self.fPluginId, i)
+        for i in range(parameterCount):
+            if i - unusedParameters == self.host.maxParameters:
+                break
+
+            paramData = self.host.get_parameter_data(self.fPluginId, i)
 
             if paramData['type'] not in (PARAMETER_INPUT, PARAMETER_OUTPUT):
+                unusedParameters += 1
                 continue
             if (paramData['hints'] & PARAMETER_IS_ENABLED) == 0:
+                unusedParameters += 1
                 continue
 
+            paramInfo   = self.host.get_parameter_info(self.fPluginId, i)
+            paramRanges = self.host.get_parameter_ranges(self.fPluginId, i)
+            paramValue  = self.host.get_current_parameter_value(self.fPluginId, i)
+
             parameter = {
                 'type':  paramData['type'],
                 'hints': paramData['hints'],
@@ -1289,6 +1307,12 @@ class PluginEdit(QDialog):
 
         QDialog.setVisible(self, yesNo)
 
+        if MACOS and yesNo:
+            parent = self.parent()
+            if parent is None:
+                return
+            gCarla.utils.cocoa_set_transient_window_for(self.windowHandle().winId(), parent.windowHandle().winId())
+
     #------------------------------------------------------------------
 
     def idleSlow(self):
